# -*- coding: utf-8 -*-

# Form implementation generated from reading ui file '/media/lg/disk2/PycharmProjects/ISAT_with_segment_anything/ISAT/ui/setting_dialog.ui'
#
# Created by: PyQt5 UI code generator 5.15.10
#
# WARNING: Any manual changes made to this file will be lost when pyuic5 is
# run again.  Do not edit this file unless you know what you are doing.


from PyQt5 import QtCore, QtGui, QtWidgets


class Ui_Dialog(object):
    def setupUi(self, Dialog):
        Dialog.setObjectName("Dialog")
        Dialog.resize(1280, 720)
        Dialog.setMinimumSize(QtCore.QSize(960, 600))
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        Dialog.setFont(font)
        self.verticalLayout_2 = QtWidgets.QVBoxLayout(Dialog)
        self.verticalLayout_2.setObjectName("verticalLayout_2")
        self.widget_2 = QtWidgets.QWidget(Dialog)
        self.widget_2.setMaximumSize(QtCore.QSize(16777215, 60))
        self.widget_2.setObjectName("widget_2")
        self.horizontalLayout = QtWidgets.QHBoxLayout(self.widget_2)
        self.horizontalLayout.setObjectName("horizontalLayout")
        self.label_4 = QtWidgets.QLabel(self.widget_2)
        self.label_4.setMaximumSize(QtCore.QSize(16777215, 16777215))
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(20)
        self.label_4.setFont(font)
        self.label_4.setObjectName("label_4")
        self.horizontalLayout.addWidget(self.label_4)
        self.verticalLayout_2.addWidget(self.widget_2)
        self.widget_21 = QtWidgets.QWidget(Dialog)
        self.widget_21.setMinimumSize(QtCore.QSize(300, 300))
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setKerning(True)
        self.widget_21.setFont(font)
        self.widget_21.setObjectName("widget_21")
        self.gridLayout = QtWidgets.QGridLayout(self.widget_21)
        self.gridLayout.setContentsMargins(0, 0, 0, 0)
        self.gridLayout.setObjectName("gridLayout")
        self.widget_23 = QtWidgets.QWidget(self.widget_21)
        self.widget_23.setObjectName("widget_23")
        self.verticalLayout_5 = QtWidgets.QVBoxLayout(self.widget_23)
        self.verticalLayout_5.setObjectName("verticalLayout_5")
        self.checkBox_polygon_invisible = QtWidgets.QCheckBox(self.widget_23)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        font.setKerning(True)
        self.checkBox_polygon_invisible.setFont(font)
        self.checkBox_polygon_invisible.setFocusPolicy(QtCore.Qt.NoFocus)
        self.checkBox_polygon_invisible.setTristate(False)
        self.checkBox_polygon_invisible.setObjectName("checkBox_polygon_invisible")
        self.verticalLayout_5.addWidget(self.checkBox_polygon_invisible)
        self.widget_7 = QtWidgets.QWidget(self.widget_23)
        self.widget_7.setObjectName("widget_7")
        self.horizontalLayout_6 = QtWidgets.QHBoxLayout(self.widget_7)
        self.horizontalLayout_6.setContentsMargins(20, -1, -1, -1)
        self.horizontalLayout_6.setObjectName("horizontalLayout_6")
        self.label_3 = QtWidgets.QLabel(self.widget_7)
        self.label_3.setObjectName("label_3")
        self.horizontalLayout_6.addWidget(self.label_3)
        self.verticalLayout_5.addWidget(self.widget_7)
        self.gridLayout.addWidget(self.widget_23, 1, 0, 1, 1)
        self.widget_27 = QtWidgets.QWidget(self.widget_21)
        self.widget_27.setObjectName("widget_27")
        self.verticalLayout_4 = QtWidgets.QVBoxLayout(self.widget_27)
        self.verticalLayout_4.setObjectName("verticalLayout_4")
        self.checkBox_auto_save = QtWidgets.QCheckBox(self.widget_27)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        font.setKerning(True)
        self.checkBox_auto_save.setFont(font)
        self.checkBox_auto_save.setFocusPolicy(QtCore.Qt.NoFocus)
        self.checkBox_auto_save.setObjectName("checkBox_auto_save")
        self.verticalLayout_4.addWidget(self.checkBox_auto_save)
        self.widget_19 = QtWidgets.QWidget(self.widget_27)
        self.widget_19.setObjectName("widget_19")
        self.horizontalLayout_18 = QtWidgets.QHBoxLayout(self.widget_19)
        self.horizontalLayout_18.setContentsMargins(20, -1, -1, -1)
        self.horizontalLayout_18.setObjectName("horizontalLayout_18")
        self.label_13 = QtWidgets.QLabel(self.widget_19)
        self.label_13.setObjectName("label_13")
        self.horizontalLayout_18.addWidget(self.label_13)
        self.verticalLayout_4.addWidget(self.widget_19)
        self.gridLayout.addWidget(self.widget_27, 0, 1, 1, 1)
        self.widget_29 = QtWidgets.QWidget(self.widget_21)
        self.widget_29.setObjectName("widget_29")
        self.verticalLayout_8 = QtWidgets.QVBoxLayout(self.widget_29)
        self.verticalLayout_8.setObjectName("verticalLayout_8")
        self.checkBox_use_bfloat16 = QtWidgets.QCheckBox(self.widget_29)
        self.checkBox_use_bfloat16.setMinimumSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        font.setKerning(True)
        self.checkBox_use_bfloat16.setFont(font)
        self.checkBox_use_bfloat16.setFocusPolicy(QtCore.Qt.NoFocus)
        self.checkBox_use_bfloat16.setObjectName("checkBox_use_bfloat16")
        self.verticalLayout_8.addWidget(self.checkBox_use_bfloat16)
        self.widget_3 = QtWidgets.QWidget(self.widget_29)
        self.widget_3.setObjectName("widget_3")
        self.horizontalLayout_2 = QtWidgets.QHBoxLayout(self.widget_3)
        self.horizontalLayout_2.setContentsMargins(20, -1, -1, -1)
        self.horizontalLayout_2.setObjectName("horizontalLayout_2")
        self.label_5 = QtWidgets.QLabel(self.widget_3)
        self.label_5.setObjectName("label_5")
        self.horizontalLayout_2.addWidget(self.label_5)
        self.verticalLayout_8.addWidget(self.widget_3)
        self.gridLayout.addWidget(self.widget_29, 2, 1, 1, 1)
        self.widget_30 = QtWidgets.QWidget(self.widget_21)
        self.widget_30.setObjectName("widget_30")
        self.verticalLayout_10 = QtWidgets.QVBoxLayout(self.widget_30)
        self.verticalLayout_10.setObjectName("verticalLayout_10")
        self.widget_15 = QtWidgets.QWidget(self.widget_30)
        self.widget_15.setObjectName("widget_15")
        self.horizontalLayout_14 = QtWidgets.QHBoxLayout(self.widget_15)
        self.horizontalLayout_14.setContentsMargins(20, 0, 0, 0)
        self.horizontalLayout_14.setObjectName("horizontalLayout_14")
        self.label_9 = QtWidgets.QLabel(self.widget_15)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        font.setKerning(True)
        self.label_9.setFont(font)
        self.label_9.setObjectName("label_9")
        self.horizontalLayout_14.addWidget(self.label_9)
        self.horizontalSlider_vertex_size = QtWidgets.QSlider(self.widget_15)
        self.horizontalSlider_vertex_size.setMaximumSize(QtCore.QSize(200, 16777215))
        self.horizontalSlider_vertex_size.setFocusPolicy(QtCore.Qt.NoFocus)
        self.horizontalSlider_vertex_size.setMaximum(5)
        self.horizontalSlider_vertex_size.setPageStep(1)
        self.horizontalSlider_vertex_size.setTracking(True)
        self.horizontalSlider_vertex_size.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalSlider_vertex_size.setTickPosition(QtWidgets.QSlider.TicksAbove)
        self.horizontalSlider_vertex_size.setObjectName("horizontalSlider_vertex_size")
        self.horizontalLayout_14.addWidget(self.horizontalSlider_vertex_size)
        self.label_vertex_size = QtWidgets.QLabel(self.widget_15)
        self.label_vertex_size.setText("")
        self.label_vertex_size.setObjectName("label_vertex_size")
        self.horizontalLayout_14.addWidget(self.label_vertex_size)
        spacerItem = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_14.addItem(spacerItem)
        self.verticalLayout_10.addWidget(self.widget_15)
        self.widget_16 = QtWidgets.QWidget(self.widget_30)
        self.widget_16.setObjectName("widget_16")
        self.horizontalLayout_15 = QtWidgets.QHBoxLayout(self.widget_16)
        self.horizontalLayout_15.setContentsMargins(20, -1, -1, -1)
        self.horizontalLayout_15.setObjectName("horizontalLayout_15")
        self.label_10 = QtWidgets.QLabel(self.widget_16)
        self.label_10.setObjectName("label_10")
        self.horizontalLayout_15.addWidget(self.label_10)
        self.verticalLayout_10.addWidget(self.widget_16)
        self.gridLayout.addWidget(self.widget_30, 4, 1, 1, 1)
        self.widget_22 = QtWidgets.QWidget(self.widget_21)
        self.widget_22.setObjectName("widget_22")
        self.verticalLayout_3 = QtWidgets.QVBoxLayout(self.widget_22)
        self.verticalLayout_3.setObjectName("verticalLayout_3")
        self.checkBox_approx_polygon = QtWidgets.QCheckBox(self.widget_22)
        self.checkBox_approx_polygon.setMinimumSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        font.setKerning(True)
        self.checkBox_approx_polygon.setFont(font)
        self.checkBox_approx_polygon.setFocusPolicy(QtCore.Qt.NoFocus)
        self.checkBox_approx_polygon.setObjectName("checkBox_approx_polygon")
        self.verticalLayout_3.addWidget(self.checkBox_approx_polygon)
        self.widget_4 = QtWidgets.QWidget(self.widget_22)
        self.widget_4.setObjectName("widget_4")
        self.horizontalLayout_5 = QtWidgets.QHBoxLayout(self.widget_4)
        self.horizontalLayout_5.setContentsMargins(20, -1, -1, -1)
        self.horizontalLayout_5.setObjectName("horizontalLayout_5")
        self.label = QtWidgets.QLabel(self.widget_4)
        self.label.setObjectName("label")
        self.horizontalLayout_5.addWidget(self.label)
        self.verticalLayout_3.addWidget(self.widget_4)
        self.gridLayout.addWidget(self.widget_22, 0, 0, 1, 1)
        self.widget_24 = QtWidgets.QWidget(self.widget_21)
        self.widget_24.setObjectName("widget_24")
        self.verticalLayout_7 = QtWidgets.QVBoxLayout(self.widget_24)
        self.verticalLayout_7.setObjectName("verticalLayout_7")
        self.checkBox_show_prompt = QtWidgets.QCheckBox(self.widget_24)
        self.checkBox_show_prompt.setMinimumSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        font.setKerning(True)
        self.checkBox_show_prompt.setFont(font)
        self.checkBox_show_prompt.setFocusPolicy(QtCore.Qt.NoFocus)
        self.checkBox_show_prompt.setObjectName("checkBox_show_prompt")
        self.verticalLayout_7.addWidget(self.checkBox_show_prompt)
        self.widget_5 = QtWidgets.QWidget(self.widget_24)
        self.widget_5.setObjectName("widget_5")
        self.horizontalLayout_4 = QtWidgets.QHBoxLayout(self.widget_5)
        self.horizontalLayout_4.setContentsMargins(20, 9, 9, 9)
        self.horizontalLayout_4.setObjectName("horizontalLayout_4")
        self.label_7 = QtWidgets.QLabel(self.widget_5)
        self.label_7.setObjectName("label_7")
        self.horizontalLayout_4.addWidget(self.label_7)
        self.verticalLayout_7.addWidget(self.widget_5)
        self.gridLayout.addWidget(self.widget_24, 2, 0, 1, 1)
        self.widget_28 = QtWidgets.QWidget(self.widget_21)
        self.widget_28.setObjectName("widget_28")
        self.verticalLayout_6 = QtWidgets.QVBoxLayout(self.widget_28)
        self.verticalLayout_6.setObjectName("verticalLayout_6")
        self.checkBox_show_edge = QtWidgets.QCheckBox(self.widget_28)
        self.checkBox_show_edge.setMinimumSize(QtCore.QSize(0, 0))
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        font.setKerning(True)
        self.checkBox_show_edge.setFont(font)
        self.checkBox_show_edge.setFocusPolicy(QtCore.Qt.NoFocus)
        self.checkBox_show_edge.setObjectName("checkBox_show_edge")
        self.verticalLayout_6.addWidget(self.checkBox_show_edge)
        self.widget_6 = QtWidgets.QWidget(self.widget_28)
        self.widget_6.setObjectName("widget_6")
        self.horizontalLayout_3 = QtWidgets.QHBoxLayout(self.widget_6)
        self.horizontalLayout_3.setContentsMargins(20, -1, -1, -1)
        self.horizontalLayout_3.setObjectName("horizontalLayout_3")
        self.label_2 = QtWidgets.QLabel(self.widget_6)
        self.label_2.setObjectName("label_2")
        self.horizontalLayout_3.addWidget(self.label_2)
        self.verticalLayout_6.addWidget(self.widget_6)
        self.gridLayout.addWidget(self.widget_28, 1, 1, 1, 1)
        self.widget_31 = QtWidgets.QWidget(self.widget_21)
        self.widget_31.setObjectName("widget_31")
        self.verticalLayout = QtWidgets.QVBoxLayout(self.widget_31)
        self.verticalLayout.setObjectName("verticalLayout")
        self.checkBox_real_time_area = QtWidgets.QCheckBox(self.widget_31)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setWeight(75)
        font.setKerning(True)
        self.checkBox_real_time_area.setFont(font)
        self.checkBox_real_time_area.setObjectName("checkBox_real_time_area")
        self.verticalLayout.addWidget(self.checkBox_real_time_area)
        self.widget_9 = QtWidgets.QWidget(self.widget_31)
        self.widget_9.setObjectName("widget_9")
        self.horizontalLayout_9 = QtWidgets.QHBoxLayout(self.widget_9)
        self.horizontalLayout_9.setContentsMargins(20, -1, -1, -1)
        self.horizontalLayout_9.setObjectName("horizontalLayout_9")
        self.label_14 = QtWidgets.QLabel(self.widget_9)
        self.label_14.setObjectName("label_14")
        self.horizontalLayout_9.addWidget(self.label_14)
        self.verticalLayout.addWidget(self.widget_9)
        self.gridLayout.addWidget(self.widget_31, 3, 0, 1, 1)
        self.widget_25 = QtWidgets.QWidget(self.widget_21)
        self.widget_25.setObjectName("widget_25")
        self.verticalLayout_9 = QtWidgets.QVBoxLayout(self.widget_25)
        self.verticalLayout_9.setObjectName("verticalLayout_9")
        self.widget_8 = QtWidgets.QWidget(self.widget_25)
        self.widget_8.setObjectName("widget_8")
        self.horizontalLayout_7 = QtWidgets.QHBoxLayout(self.widget_8)
        self.horizontalLayout_7.setContentsMargins(20, 0, 0, 0)
        self.horizontalLayout_7.setObjectName("horizontalLayout_7")
        self.label_6 = QtWidgets.QLabel(self.widget_8)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        font.setKerning(True)
        self.label_6.setFont(font)
        self.label_6.setObjectName("label_6")
        self.horizontalLayout_7.addWidget(self.label_6)
        self.horizontalSlider_mask_alpha = QtWidgets.QSlider(self.widget_8)
        self.horizontalSlider_mask_alpha.setMaximumSize(QtCore.QSize(200, 16777215))
        self.horizontalSlider_mask_alpha.setFocusPolicy(QtCore.Qt.NoFocus)
        self.horizontalSlider_mask_alpha.setMaximum(10)
        self.horizontalSlider_mask_alpha.setOrientation(QtCore.Qt.Horizontal)
        self.horizontalSlider_mask_alpha.setInvertedAppearance(False)
        self.horizontalSlider_mask_alpha.setInvertedControls(False)
        self.horizontalSlider_mask_alpha.setTickPosition(QtWidgets.QSlider.TicksAbove)
        self.horizontalSlider_mask_alpha.setObjectName("horizontalSlider_mask_alpha")
        self.horizontalLayout_7.addWidget(self.horizontalSlider_mask_alpha)
        self.label_mask_alpha = QtWidgets.QLabel(self.widget_8)
        self.label_mask_alpha.setText("")
        self.label_mask_alpha.setObjectName("label_mask_alpha")
        self.horizontalLayout_7.addWidget(self.label_mask_alpha)
        spacerItem1 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_7.addItem(spacerItem1)
        self.verticalLayout_9.addWidget(self.widget_8)
        self.widget_14 = QtWidgets.QWidget(self.widget_25)
        self.widget_14.setObjectName("widget_14")
        self.horizontalLayout_13 = QtWidgets.QHBoxLayout(self.widget_14)
        self.horizontalLayout_13.setContentsMargins(20, -1, -1, -1)
        self.horizontalLayout_13.setObjectName("horizontalLayout_13")
        self.label_8 = QtWidgets.QLabel(self.widget_14)
        self.label_8.setObjectName("label_8")
        self.horizontalLayout_13.addWidget(self.label_8)
        self.verticalLayout_9.addWidget(self.widget_14)
        self.gridLayout.addWidget(self.widget_25, 3, 1, 1, 1)
        self.widget_26 = QtWidgets.QWidget(self.widget_21)
        self.widget_26.setObjectName("widget_26")
        self.verticalLayout_11 = QtWidgets.QVBoxLayout(self.widget_26)
        self.verticalLayout_11.setObjectName("verticalLayout_11")
        self.widget_17 = QtWidgets.QWidget(self.widget_26)
        self.widget_17.setObjectName("widget_17")
        self.horizontalLayout_16 = QtWidgets.QHBoxLayout(self.widget_17)
        self.horizontalLayout_16.setContentsMargins(20, 0, 0, 0)
        self.horizontalLayout_16.setObjectName("horizontalLayout_16")
        self.label_11 = QtWidgets.QLabel(self.widget_17)
        font = QtGui.QFont()
        font.setFamily("Times New Roman")
        font.setPointSize(12)
        font.setBold(True)
        font.setItalic(False)
        font.setWeight(75)
        font.setKerning(True)
        self.label_11.setFont(font)
        self.label_11.setObjectName("label_11")
        self.horizontalLayout_16.addWidget(self.label_11)
        self.comboBox_contour_mode = QtWidgets.QComboBox(self.widget_17)
        self.comboBox_contour_mode.setMinimumSize(QtCore.QSize(120, 0))
        self.comboBox_contour_mode.setFocusPolicy(QtCore.Qt.ClickFocus)
        self.comboBox_contour_mode.setObjectName("comboBox_contour_mode")
        self.comboBox_contour_mode.addItem("")
        self.comboBox_contour_mode.addItem("")
        self.comboBox_contour_mode.addItem("")
        self.horizontalLayout_16.addWidget(self.comboBox_contour_mode)
        spacerItem2 = QtWidgets.QSpacerItem(40, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_16.addItem(spacerItem2)
        self.verticalLayout_11.addWidget(self.widget_17)
        self.widget_18 = QtWidgets.QWidget(self.widget_26)
        self.widget_18.setObjectName("widget_18")
        self.horizontalLayout_17 = QtWidgets.QHBoxLayout(self.widget_18)
        self.horizontalLayout_17.setContentsMargins(20, -1, -1, -1)
        self.horizontalLayout_17.setObjectName("horizontalLayout_17")
        self.label_12 = QtWidgets.QLabel(self.widget_18)
        self.label_12.setObjectName("label_12")
        self.horizontalLayout_17.addWidget(self.label_12)
        self.verticalLayout_11.addWidget(self.widget_18)
        self.gridLayout.addWidget(self.widget_26, 4, 0, 1, 1)
        self.verticalLayout_2.addWidget(self.widget_21)
        self.widget = QtWidgets.QWidget(Dialog)
        self.widget.setMaximumSize(QtCore.QSize(16777215, 30))
        self.widget.setObjectName("widget")
        self.horizontalLayout_8 = QtWidgets.QHBoxLayout(self.widget)
        self.horizontalLayout_8.setContentsMargins(0, 0, 0, 0)
        self.horizontalLayout_8.setObjectName("horizontalLayout_8")
        spacerItem3 = QtWidgets.QSpacerItem(1173, 20, QtWidgets.QSizePolicy.Expanding, QtWidgets.QSizePolicy.Minimum)
        self.horizontalLayout_8.addItem(spacerItem3)
        self.pushButton_close = QtWidgets.QPushButton(self.widget)
        self.pushButton_close.setObjectName("pushButton_close")
        self.horizontalLayout_8.addWidget(self.pushButton_close)
        self.verticalLayout_2.addWidget(self.widget)

        self.retranslateUi(Dialog)
        QtCore.QMetaObject.connectSlotsByName(Dialog)

    def retranslateUi(self, Dialog):
        _translate = QtCore.QCoreApplication.translate
        Dialog.setWindowTitle(_translate("Dialog", "Setting"))
        self.label_4.setText(_translate("Dialog", "Setting"))
        self.checkBox_polygon_invisible.setText(_translate("Dialog", "Polygons invisible"))
        self.label_3.setText(_translate("Dialog", "Hide polygons when in create mode."))
        self.checkBox_auto_save.setText(_translate("Dialog", "Auto save"))
        self.label_13.setText(_translate("Dialog", "Auto save."))
        self.checkBox_use_bfloat16.setText(_translate("Dialog", "Use bfloat16"))
        self.label_5.setText(_translate("Dialog", "Run sam on bfloat16 for smaller GPU memory footprint."))
        self.label_9.setText(_translate("Dialog", "Vertex size"))
        self.label_10.setText(_translate("Dialog", "The size of polygon vertexs."))
        self.checkBox_approx_polygon.setText(_translate("Dialog", "Approx polygon"))
        self.label.setText(_translate("Dialog", "Reduce the number of polygon vertics when genetating polygons from masks."))
        self.checkBox_show_prompt.setText(_translate("Dialog", "Show prompt"))
        self.label_7.setText(_translate("Dialog", "Show prompt point when using SAM."))
        self.checkBox_show_edge.setText(_translate("Dialog", "Show edge"))
        self.label_2.setText(_translate("Dialog", "Show edges of polygons."))
        self.checkBox_real_time_area.setText(_translate("Dialog", "Real time area"))
        self.label_14.setText(_translate("Dialog", "Calculate the area in real time while editing the polygon. If False update only when saving."))
        self.label_6.setText(_translate("Dialog", "Mask alpha"))
        self.label_8.setText(_translate("Dialog", "The transparency of the masks generated by SAM."))
        self.label_11.setText(_translate("Dialog", "Contour mode"))
        self.comboBox_contour_mode.setItemText(0, _translate("Dialog", "External"))
        self.comboBox_contour_mode.setItemText(1, _translate("Dialog", "Max only"))
        self.comboBox_contour_mode.setItemText(2, _translate("Dialog", "All"))
        self.label_12.setText(_translate("Dialog", "Contour saving mode. External contours or only max contour or all contours."))
        self.pushButton_close.setText(_translate("Dialog", "&Close"))
